%%
%% This is file `dps_str_us.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% dps.dtx  (with options: `copyright,english')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% dps.sty package,             2006-10-06              %%
%% Copyright (C) 2006  D. P. Story                      %%
%%   storyd@owc.edu                                     %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\chooseQ{"You must choose a question to answer before you answer!"}
\def\triedTooMuch{"You have tried this problem too many times, I'm adding "
    + \dspenaltypoints
    + " points, and resetting the penalty counter. Bad boy/girl!"}
\def\congratFinished{"Student: " + (this.getField("dpsSignInName").value) + ". "
        + "Time stamp: " + (util.printd("mm-dd-yy, H:MM:ss.", new Date())) +"\n"
        +"Congratulations! You finished the puzzle"
        +((nMissed==0) ? " without missing a single problem, amazing!"
        : ", but you missed " + nMissed + " questions in the process!")}
\def\regretPleased{(( nMissed > n )
        ? "I regret to report that you did not pass the test because you missed too many questions."
        : "I am pleased to report that you passed the test!")}
\def\reportPenaltyPoints{"The number of penalty points is " + nPenaltyPoints +"."}
\def\finalPenaltyScore{"Final penalty score is " + nTotalPenaltyPoints + ". "}
\def\aPenaltyScale{[-1,0], [0,4], [4, 10], [10,25], [25,5000]}
\def\aPenaltyMsgs
{%
    "Perfect! You are a statistics wizard!",
    "Very nice performance!",
    "This is not looking good. Perhaps a review is in order!",
    "Are you trying? Do you have the prerequisites for this course?",
    "You're not taking this seriously!"
}
\endinput
%%
%% End of file `dps_str_us.def'.
