%%
%% This is file `unicodes1.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% aeb_pro.dtx  (with options: `copyright,unicode1')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% aeb_pro.sty package,                  2006-9-08      %%
%% Copyright (C) 2006  D. P. Story                      %%
%%   dpstory@acrotex.net                                %%
%%                                                      %%
%% This program can redistributed and/or modified under %%
%% the terms of the LaTeX Project Public License        %%
%% Distributed from CTAN archives in directory          %%
%% macros/latex/base/lppl.txt; either version 1 of the  %%
%% License, or (at your option) any later version.      %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\convertChriiUnicode{¡}{00A1}
\convertChriiUnicode{¢}{00A2}
\convertChriiUnicode{£}{00A3}
\convertChriiUnicode{¤}{00A4}
\convertChriiUnicode{¥}{00A5}
\convertChriiUnicode{¦}{00A6}
\convertChriiUnicode{§}{00A7}
\convertChriiUnicode{¨}{00A8}
\convertChriiUnicode{©}{00A9}
\convertChriiUnicode{ª}{00AA}
\convertChriiUnicode{«}{00AB}
\convertChriiUnicode{¬}{00AC}
\convertChriiUnicode{­}{00AD}
\convertChriiUnicode{®}{00AE}
\convertChriiUnicode{¯}{00AF}
\convertChriiUnicode{°}{00B0}
\convertChriiUnicode{±}{00B1}
\convertChriiUnicode{²}{00B2}
\convertChriiUnicode{³}{00B3}
\convertChriiUnicode{´}{00B4}
\convertChriiUnicode{µ}{00B5}
\convertChriiUnicode{¶}{00B6}
\convertChriiUnicode{·}{00B7}
\convertChriiUnicode{¸}{00B8}
\convertChriiUnicode{¹}{00B9}
\convertChriiUnicode{º}{00BA}
\convertChriiUnicode{»}{00BB}
\convertChriiUnicode{¼}{00BC}
\convertChriiUnicode{½}{00BD}
\convertChriiUnicode{¾}{00BE}
\convertChriiUnicode{¿}{00BF}
\convertChriiUnicode{À}{00C0}
\convertChriiUnicode{Á}{00C1}
\convertChriiUnicode{Â}{00C2}
\convertChriiUnicode{Ã}{00C3}
\convertChriiUnicode{Ä}{00C4}
\convertChriiUnicode{Å}{00C5}
\convertChriiUnicode{Æ}{00C6}
\convertChriiUnicode{Ç}{00C7}
\convertChriiUnicode{È}{00C8}
\convertChriiUnicode{É}{00C9}
\convertChriiUnicode{Ê}{00CA}
\convertChriiUnicode{Ë}{00CB}
\convertChriiUnicode{Ì}{00CC}
\convertChriiUnicode{Í}{00CD}
\convertChriiUnicode{Î}{00CE}
\convertChriiUnicode{Ï}{00CF}
\convertChriiUnicode{Ð}{00D0}
\convertChriiUnicode{Ñ}{00D1}
\convertChriiUnicode{Ò}{00D2}
\convertChriiUnicode{Ó}{00D3}
\convertChriiUnicode{Ô}{00D4}
\convertChriiUnicode{Õ}{00D5}
\convertChriiUnicode{Ö}{00D6}
\convertChriiUnicode{×}{00D7}
\convertChriiUnicode{Ø}{00D8}
\convertChriiUnicode{Ù}{00D9}
\convertChriiUnicode{Ú}{00DA}
\convertChriiUnicode{Û}{00DB}
\convertChriiUnicode{Ü}{00DC}
\convertChriiUnicode{Ý}{00DD}
\convertChriiUnicode{Þ}{00DE}
\convertChriiUnicode{ß}{00DF}
\convertChriiUnicode{à}{00E0}
\convertChriiUnicode{á}{00E1}
\convertChriiUnicode{â}{00E2}
\convertChriiUnicode{ã}{00E3}
\convertChriiUnicode{ä}{00E4}
\convertChriiUnicode{å}{00E5}
\convertChriiUnicode{æ}{00E6}
\convertChriiUnicode{ç}{00E7}
\convertChriiUnicode{è}{00E8}
\convertChriiUnicode{é}{00E9}
\convertChriiUnicode{ê}{00EA}
\convertChriiUnicode{ë}{00EB}
\convertChriiUnicode{ì}{00EC}
\convertChriiUnicode{í}{00ED}
\convertChriiUnicode{î}{00EE}
\convertChriiUnicode{ï}{00EF}
\convertChriiUnicode{ð}{00F0}
\convertChriiUnicode{ñ}{00F1}
\convertChriiUnicode{ò}{00F2}
\convertChriiUnicode{ó}{00F3}
\convertChriiUnicode{ô}{00F4}
\convertChriiUnicode{õ}{00F5}
\convertChriiUnicode{ö}{00F6}
\convertChriiUnicode{÷}{00F7}
\convertChriiUnicode{ø}{00F8}
\convertChriiUnicode{ù}{00F9}
\convertChriiUnicode{ú}{00FA}
\convertChriiUnicode{û}{00FB}
\convertChriiUnicode{ü}{00FC}
\convertChriiUnicode{ý}{00FD}
\convertChriiUnicode{þ}{00FE}
\convertChriiUnicode{ÿ}{00FF}
\endinput
%%
%% End of file `unicodes1.def'.
